package Weed::Fields;
use Weed::Perl;

use Weed::Fields::SFNode;

use Weed::Fields::MFNode;

1;
__END__
